@@ -6,7 +6,7 @@ import json
 from velbus.message import Message
 from velbus.command_registry import register_command
 
-COMMAND_CODE = 0xfb
+COMMAND_CODE = 0xFB
 
 CHANNEL_NORMAL = 0x00
 
@@ -62,18 +62,18 @@ class RelayStatusMessage(Message):
         self.disable_inhibit_forced = data[1]
         self.status = data[2]
         self.led_status = data[3]
-        (self.delay_time,) = struct.unpack('>L', bytes([0]) + data[4:])
+        (self.delay_time,) = struct.unpack(">L", bytes([0]) + data[4:])
 
     def to_json(self):
         """
         :return: str
         """
         json_dict = self.to_json_basic()
-        json_dict['channel'] = self.channel
-        json_dict['disable_inhibit_forced'] = self.disable_inhibit_forced
-        json_dict['status'] = self.status
-        json_dict['led_status'] = self.led_status
-        json_dict['delay_time'] = self.delay_time
+        json_dict["channel"] = self.channel
+        json_dict["disable_inhibit_forced"] = self.disable_inhibit_forced
+        json_dict["status"] = self.status
+        json_dict["led_status"] = self.led_status
+        json_dict["delay_time"] = self.delay_time
         return json.dumps(json_dict)
 
     def is_normal(self):
@@ -116,7 +116,7 @@ class RelayStatusMessage(Message):
         """
         :return: bool
         """
-        if ((self.status >> (self.channel-1)) & 1 != 0):
+        if (self.status >> (self.channel - 1)) & 1 != 0:
             return True
         else:
             return False
@@ -131,13 +131,18 @@ class RelayStatusMessage(Message):
         """
         :return: bytes
         """
-        return bytes([
-            COMMAND_CODE,
-            self.channels_to_byte([self.channel]),
-            self.disable_inhibit_forced,
-            self.status,
-            self.led_status
-        ]) + struct.pack('>L', self.delay_time)[-3:]
+        return (
+            bytes(
+                [
+                    COMMAND_CODE,
+                    self.channels_to_byte([self.channel]),
+                    self.disable_inhibit_forced,
+                    self.status,
+                    self.led_status,
+                ]
+            )
+            + struct.pack(">L", self.delay_time)[-3:]
+        )
 
 
 register_command(COMMAND_CODE, RelayStatusMessage)
